use Test::More tests => 1;

BEGIN {
use_ok( 'Catalyst::Authentication::Credential::OpenID' );
# use_ok( 'Catalyst::Authentication::Store::OpenID' );
}

diag( "Testing Catalyst::Authentication::Credential::OpenID $Catalyst::Authentication::Credential::OpenID::VERSION" );
